/**
 * @file
 * Connect Drupal.behaviors to htmx inserted content.
 *
 * Note: content inserted using data-hx-swap-oob does not trigger this event.
 * That content is attached in Drupal.behaviors.htmxSwapOob.
 */

/**
 * Establish event-listener for htmx:load.
 *
 * @type {Drupal~behavior}
 *
 * @prop {Drupal~behaviorAttach} attach
 *   Calls Drupal JS to attach behaviors to html loaded by htmx.
 */
Drupal.behaviors.htmxAttachBehaviors = {
  attach: function (context, settings) {
    once('htmxAttachBehaviors', 'body', context).forEach(function (element) {
      element.addEventListener('htmx:load', function (htmxLoadEvent) {
        // The attachBehaviors method searches within the context.
        // We need to go up one level so that the loaded content is processed
        // completely.
        Drupal.attachBehaviors(htmxLoadEvent.detail.elt.parentElement, settings);
      });
    });
  },
};
